@@ -47,9 +47,11 @@ def _send_email(recipient, subject, html_message, text_message):
     # Send email using Flash-Mail
     try:
         current_app.mail.send(message)
-    except (socket.gaierror, socket.error) as e:
+
+    # Print helpful error messages on exceptions
+    except (socket.gaierror, socket.error) as e:    # pragma: no coverage
         raise EmailException('Connection error: Check your MAIL_HOSTNAME or MAIL_PORT settings.')
-    except smtplib.SMTPAuthenticationError:
+    except smtplib.SMTPAuthenticationError:         # pragma: no coverage
         raise EmailException('SMTP Authentication error: Check your MAIL_USERNAME and MAIL_PASSWORD settings.')
 
 
