@@ -49,6 +49,7 @@ def change_password():
 
     # Initialize form
     form = user_manager.change_password_form(request.form)
+    form.next.data = request.args.get('next', '/')  # Place ?next query param in next form field
 
     # Process valid POST
     if request.method=='POST' and form.validate():
@@ -61,11 +62,8 @@ def change_password():
         # Prepare one-time system message
         flash(_('Your password has been changed successfully.'), 'success')
 
-        # Redirect to 'next' URL or '/'
-        next = form.next.data
-        if not next:
-            return redirect('/')
-        return redirect(next)
+        # Redirect to 'next' URL
+        return redirect(form.next.data)
 
     # Process GET or invalid POST
     return render_template(user_manager.change_password_template, form=form)
@@ -80,6 +78,7 @@ def change_username():
 
     # Initialize form
     form = user_manager.change_username_form(request.form)
+    form.next.data = request.args.get('next', '/')  # Place ?next query param in next form field
 
     # Process valid POST
     if request.method=='POST' and form.validate():
@@ -91,17 +90,13 @@ def change_username():
         # Prepare one-time system message
         flash(_("Your username has been changed to '%(username)s'.", username=new_username), 'success')
 
-        # Redirect to 'next' URL or '/'
-        next = form.next.data
-        if not next:
-            return redirect('/')
-        return redirect(next)
+        # Redirect to 'next' URL
+        return redirect(form.next.data)
 
     # Process GET or invalid POST
     return render_template(user_manager.change_username_template, form=form)
 
 
-# TODO:
 def forgot_password():
     """
     Prompt for email and send reset password email.
@@ -145,6 +140,7 @@ def login():
 
     # Initialize form
     form = user_manager.login_form(request.form)
+    form.next.data = request.args.get('next', '/')  # Place ?next query param in next form field
 
     # Process valid POST
     if request.method=='POST' and form.validate():
@@ -162,11 +158,8 @@ def login():
                 # Prepare one-time system message
                 flash(_('You have signed in successfully.'), 'success')
 
-                # Redirect to 'next' URL or '/'
-                next = form.next.data
-                if not next:
-                    return redirect('/')
-                return redirect(next)
+                # Redirect to 'next' URL
+                return redirect(form.next.data)
             else:
                 if user_manager.enable_confirm_email and not user.email_confirmed_at:
                     flash(_('Your email address has not yet been confirmed. Check your email Inbox and Spam folders for the confirmation email and follow the instructions to activate your account.'), 'error')
@@ -284,7 +277,6 @@ def resend_confirmation_email():
     # return render_template(user_manager.resend_confirmation_email_template, form=form)
 
 
-# TODO:
 def reset_password(token):
     """
     Verify the password reset token, Prompt for new password, and set the user's password.
